# cgmlst_chewbbaca snakemake workflow

import os
import pandas as pd
import shutil
shell.executable("bash")

shell.executable("bash")

# Settings ------------------------------------------------------------


# Set snakemake main workdir variable

workdir: config["workdir"]

samples = pd.read_csv(config["samples"], index_col="sample", sep = "\t")
samples.index = samples.index.astype('str', copy=False) # in case samples are integers, need to convert them to str


# Functions ------------------------------------------------------------

def _get_assembly(wildcards,file='assembly'):
    return samples.loc[(wildcards.sample), [file]].dropna()[0]


# rules ------------------------------------------------------------

rule all:
    input:
        expand("cgmlst/{sample}/results_alleles.tsv", sample=samples.index),
        "cgmlst/distance_matrix.tsv",
        "cgmlst/grapetree_mstree.tre",
        "cgmlst/allele_statistics.tsv",
        "cgmlst/error_counts.tsv",
        "reports/cgmlst_report.html",
        "cgmlst/timestamps.tsv",
        "cgmlst/hashids.tsv",
        expand("cgmlst/{sample}/allele_length.tsv", sample=samples.index) if config["parameters"]["frameshift_removal"]["remove_frameshifts"] else [], # frameshift detection
        "cgmlst/summary_masked_loci.tsv" if config["parameters"]["frameshift_removal"]["remove_frameshifts"] else [], # frameshift detection

rule all_chewbbaca:
    input:
        "cgmlst/error_counts.tsv",
        expand("cgmlst/{sample}/results_alleles.tsv", sample=samples.index)


rule all_hashed:
    input:
        "cgmlst/error_counts.tsv",
        expand("cgmlst/{sample}/results_alleles.tsv", sample=samples.index),
        "cgmlst/distance_matrix.tsv"


rule all_unhashed:
    input:
        expand("cgmlst/{sample}/results_alleles.tsv", sample=samples.index),
        "cgmlst/distance_matrix.tsv",
        "cgmlst/distance_matrix_unhashed.tsv",
        "cgmlst/grapetree_mstree_unhashed.tre"
        "cgmlst/allele_statistics.tsv",
        "cgmlst/error_counts.tsv"

rule all_report:
    input:
        "cgmlst/error_counts.tsv",
        expand("cgmlst/{sample}/results_alleles.tsv", sample=samples.index),
        "cgmlst/distance_matrix.tsv",
        "reports/cgmlst_report.html",


rule all_clustering:
    input:
        "cgmlst/error_counts.tsv",
        expand("cgmlst/{sample}/results_alleles.tsv", sample=samples.index),
        "cgmlst/distance_matrix.tsv",
        "cgmlst/distance_matrix_unhashed.tsv",
        "cgmlst/clustering"


rule all_database_comparison:
    input:
        "cgmlst/allele_statistics.tsv",
        "cgmlst_joined/distance_matrix.tsv",
        "cgmlst_joined/allele_profiles.tsv",
        "cgmlst_joined/allele_profiles_filtered.tsv",
        "cgmlst_joined/distance_matrix_filtered.tsv",
        "reports/cgmlst_comparison_report.html",
        "cgmlst/timestamps.tsv",
        "cgmlst_joined/hashids.tsv",
        expand("cgmlst/{sample}/allele_length.tsv", sample=samples.index) if config["parameters"]["frameshift_removal"]["remove_frameshifts"] else [], # frameshift detection


# include rules --------
include: "rules/allele_calling.smk"
include: "rules/grapetree.smk"
include: "rules/clustering.smk"
include: "rules/reporting.smk"
include: "rules/joining.smk"
include: "rules/hashid.smk"


# logging information---------

onstart:
    shell('echo -e "running\t`date`" > pipeline_status.txt')

onsuccess:
    shell('echo -e "success\t`date`" > pipeline_status.txt')
    print("Workflow finished, no error")

onerror:
    shell('echo -e "error\t`date`" > pipeline_status.txt'),
    print("An error occurred")
