#!/bin/bash
set -euo pipefail

# Select branch or tag
GIT_BRANCH="3.0.0"

# Pull the latest version of the image, in order to populate the build cache:
docker pull bfrbioinformatics/chewiesnake:databases || true
docker pull bfrbioinformatics/chewiesnake:conda     || true

# Build the application stage, using cached databases & testdata stage:
echo "Building bfrbioinformatics/chewiesnake:conda"
buildbegin=$(date +"%Y-%m-%d %H:%M:%S")
docker build --target conda \
       --cache-from=bfrbioinformatics/chewiesnake:databases \
       --cache-from=bfrbioinformatics/chewiesnake:testdata \
       --cache-from=bfrbioinformatics/chewiesnake:conda \
       --build-arg CONDA_ENV_NAME=$(head -1 ../../envs/chewiesnake_docker.yaml | cut -d' ' -f2) \
       --build-arg GIT_BRANCH=$GIT_BRANCH \
       --build-arg GIT_SHA1=$(git ls-remote https://gitlab.com/bfr_bioinformatics/chewieSnake.git --branch $GIT_BRANCH | awk '{ print $1}') \
       --build-arg BUILD_DATE=$(date +"%Y%m%d%H%M%S") \
       --tag bfrbioinformatics/chewiesnake:conda .
buildfinish=$(date +"%Y-%m-%d %H:%M:%S")

# Build duration on Gandalf: 6 min 30 sec
echo "Building time from $buildbegin till $buildfinish"

# Push the new versions:
echo "Pushing bfrbioinformatics/chewiesnake:conda"
docker push bfrbioinformatics/chewiesnake:conda

# sha256:acb7f5f80c811c1d8c2043827353fad28d7dae520256932189a3fd30a09a640f
