# rules that create an rmarkdown report

rule report:
    input:
        distance_matrix = "cgmlst/distance_matrix.tsv",
        allele_stats = "cgmlst/allele_statistics.tsv",
        nwk  = "cgmlst/grapetree_mstree.tre",
        timestamps = "cgmlst/timestamps.tsv",
        hashids="cgmlst/hashids.tsv",
        masked_loci =  "cgmlst/summary_masked_loci.tsv" if config["parameters"]["frameshift_removal"]["remove_frameshifts"] else [], # frameshift detection
    output:
        report = "reports/cgmlst_report.html"
    log: "logs/rmarkdown_report.log"
    params:
        workdir = config["workdir"],
        exportpath = "cgmlst/exported_trees",
        export = True,
        distance_threshold = config["parameters"]["clustering"]["distance_threshold"],
        clustering_method = config["parameters"]["clustering"]["clustering_method"],
        threshold_range = config["parameters"]["clustering"]["address_range"],
        parameters = config["parameters"],
        remove_frameshifts = config["parameters"]["frameshift_removal"]["remove_frameshifts"],
    conda: "../envs/rmarkdown.yaml"
    message: "Creating Rmarkdown report"
    script:
        "../scripts/report.Rmd"


rule comparison_report:
    input:
        workdir = config["workdir"],
        sample_meta = "cgmlst_joined/samples_related_meta.tsv",
        samples_related = "cgmlst_joined/samples_related.txt",
        match_overview = "cgmlst_joined/match_summary.txt",
        distance_matrix_filtered = "cgmlst_joined/distance_matrix_filtered.tsv",
        distance_matrix = "cgmlst_joined/distance_matrix.tsv",
        allele_stats = "cgmlst/allele_statistics.tsv",
        mstree_all = "cgmlst_joined/grapetree_mstree.tre",
        mstree_filtered = "cgmlst_joined/grapetree_mstree_filtered.tre",
        hashids="cgmlst/hashids.tsv",
    output:
        report = "reports/cgmlst_comparison_report.html"
    log: "logs/comparison_report.log"
    message: "Create comparison report"
    params:
        name = "external",
        outdir = "cgmlst_joined/",
        samplesheet = config["samples"],
        clustering_method = config["parameters"]["clustering"]["clustering_method"],
        workdir = config["workdir"],
        clustering_threshold = config["parameters"]["clustering"]["distance_threshold"], # this value is not for pre-selection but only for clustering
        threshold_range = config["parameters"]["clustering"]["address_range"],
        parameters = config["parameters"],
        comparison_db = config["parameters"]["clustering"]["comparison_allele_database"],
    conda:
       "../envs/rmarkdown.yaml"
    script:
        "../scripts/report_comparison.Rmd"
