#!/usr/bin/env Rscript

# subset distance matrix

# define data ---
debug <- F
if(debug){

  # input
  workdir <- "/home/carlus/BfR/Projects/salmonella-alleledb"
  cluster <- "Theon"
  samples_in_cluster.file <- file.path(workdir, "merged_db","clustering",paste0("samples_",cluster,".tsv"))
  full_distance_matrix.file <- file.path(workdir,"merged_db/distance_matrix.tsv")
  #output:
  subset_distance_matrix.file <- file.path(workdir, "merged_db","clustering",cluster,"distance_matrix.tsv")

  do_cluster <- T
} else {

# input
samples_in_cluster.file <- snakemake@input[["samples_in_cluster"]]
full_distance_matrix.file <- snakemake@input[["distance_matrix_tsv"]]
#output:
subset_distance_matrix.file <- snakemake@output[["distance_matrix_tsv"]]

# parameters
functions_file <- file.path(snakemake@params[["functions_file"]],"scripts/functions.R")
do_cluster <- snakemake@params[["cluster_matrix"]]
# log
log <- file(snakemake@log[[1]], open="wt")
# redirect output to log file
sink(log)
sink(log, type="message")

}

# load functions ----

print(paste("File to functions.R",functions_file))

if(! file.exists(functions_file)) stop("Function file",functions_file,"does NOT exist")

source(functions_file)

# load data

samples_in_cluster <- read.delim(samples_in_cluster.file)


full_distance_matrix <- read_distance_matrix(full_distance_matrix.file,sep = " ", header = F) # space separated, no header

# execution

samples_selected <- row.names(full_distance_matrix) %in% samples_in_cluster$sample
subset_distance_matrix <- full_distance_matrix[samples_selected,samples_selected]


# cluster, rearrange matrix

if(do_cluster){
  subset_distance_matrix <- reorder_cormat(subset_distance_matrix)  
}


# write out
write.table(subset_distance_matrix, subset_distance_matrix.file, sep="\t",row.names = T, col.names = NA, quote = F)



