#!/usr/bin/env Rscript

# Goal: Compute median allele size per locus

suppressPackageStartupMessages(require(Biostrings))


# define data
debug <- F

if(debug){
  scheme_dir <- "/home/carlus/BfR/Projects/chewbbaca_frameshifts/Schemes/Listeria_cgmlst_Ruppitsch_chewbbaca/cgmlst"
  outfile <- "/home/carlus/BfR/Projects/chewbbaca_frameshifts/pipeline_test/components/median_allele_length.tsv"
} else {
  scheme_dir <- snakemake@input[["scheme_dir"]]
  outfile <- snakemake@output[["scheme_length_profile"]]
}

loci <- list.files(scheme_dir, pattern = ".fasta$", full.names = T)

# load data and compute median length
median_allelelength <- sapply(loci, function(locus){
  
  fasta <- readDNAStringSet(locus)
  
  allele_lengths <- width(fasta)
  median_length <- median(allele_lengths)
  
  return(median_length)
  
})
names(median_allelelength) <- basename(loci)

# convert to data.frame
median_allelelength.df <- data.frame(locus= names(median_allelelength), length = median_allelelength)

# write output
write.table(median_allelelength.df, file = outfile, sep = "\t", quote = F, row.names = F)
