#!/bin/bash
#set -e
#set -u
#set -o pipefail

# create allele_database sheet


# get all profiles
#find `pwd` -name allele_profiles*
#find `pwd` -name allele_stat*


## Helpfile and escape
if [ $# -eq 0 ]; then
    echo "Please provide at least one argument. For the help file, type create_alleledbSheet.sh --help"
    [[ "$0" = "$BASH_SOURCE" ]] && exit 1 || return 1
fi


## search for "--help" flag
if [[ $@ =~ '--help' || $@ =~ '-h' ]]; then
    echo "Help file ----------------------"
    echo "Basic usage: create_alleledbSheet.sh inputbasedir[Options]"
    echo
    echo "Positional arguments"
    echo "inputdir: Basepath with alelle_profiles.tsv in subdirectories"

    echo
    echo "Optional flags:"
    echo "--interactive Ask before execution"
    echo "--force Re-build database"
    
    [[ "$0" = "$BASH_SOURCE" ]] && exit 1 || return 1
fi   



# needs matching?

basedir="$1" #"/cephfs/abteilung4/Projects_NGS/GenoSalmSurv/realtime_cgmlst/dummy_db"

allele_sheet="$basedir/samples.tsv"


if [[ $@ =~ '--interactive' ]]; then
    interactive=true
else 
    interactive=false
fi


if [[ $@ =~ '--force' ]]; then
    force=true
else 
    force=false
fi

echo "$force"

if [[ $force == false ]]; then
echo "Not Forcing"
else
echo "Forcing"
fi

if [[ -f $allele_sheet && $force == false ]]; then
    echo "allele_sheet $allele_sheet already exists. Use --force to overwrite"
    [[ "$0" = "$BASH_SOURCE" ]] && exit 1 || return 1
fi

# Print parameters
echo "Parameters:"
echo "outdir: $basedir"
echo "force: $force"
echo

# ask if in interactive mode
if [[ $interactive == true ]]
then
	read -p "Do you want to continue? " -n 1 -r
	echo
	if [[ ! $REPLY =~ ^[Yy]$ ]]
	then
		[[ "$0" = "$BASH_SOURCE" ]] && exit 1 || return 1
	fi
fi



# ----------------------------------------------------------------------


echo -e "sender\tprofiles\tstatistics\ttimestamps" > $allele_sheet

#for mydir in `ls -d $basedir/*/allele_profiles.tsv`; do
for myprofile in `ls -d $basedir/*/allele_profiles.tsv`; do
#for mydir in `ls -d $basedir/*/`; do


    echo $myprofile
    mydir=$(dirname $myprofile)

    echo "$mydir"

    if [[ $mydir =~ "logs" ]];then
        echo "Skipping logs"
        continue
    #else 
    #    echo "Not skipping logs"
    fi
    

    if [[ $mydir =~ "merged_db" ]];then
        echo "Skipping merged_db"
        continue
    #else 
    #    echo "Not skipping logs"
    fi
    
    
    sender=`basename $mydir`
    echo "sender: $sender"
    
    profiles=$myprofile

    #if [[ -f $mydir/allele_profiles.tsv ]]; then
        #profiles="${mydir}allele_profiles.tsv"
    #else 
        #profiles="NA"
    #fi
    
    if [[ -f $mydir/allele_statistics.tsv ]]; then
        statistics="${mydir}/allele_statistics.tsv"
    else 
        touch "${mydir}/allele_statistics.tsv"
        statistics="${mydir}/allele_statistics.tsv"
        #statistics="NA"
    fi

    if [[ -f $mydir/timestamps.tsv ]]; then
        timestamps="${mydir}/timestamps.tsv"
    else 
        touch "${mydir}/timestamps.tsv"
        #timestamps="${mydir}/timestamps.tsv"
        timestamps=="NA"
    fi

    
    
    #metadata=`ls $mydir/metadata.tsv`
    
    
    echo -e "$sender\t$profiles\t$statistics\t$timestamps" >> $allele_sheet

done
